Module sync

Module sync 

Synchronous hybrid optical-image writer API.

Modules

writer
Main writer for creating hybrid ISO+UDF images

Structs

Borrowed
Reborrow a Hadris I/O value without requiring a blanket implementation for &mut T.
OpticalImageWriter
Writer for creating hybrid ISO+UDF CD/DVD images

Enums

SeekFrom
Enumeration of possible methods to seek within an I/O object.

Traits

Read
Read bytes from a source.
Seek
Move within a stream.
Write
Write bytes to a destination.