Module sync

Module sync 

Modules

writer
Main writer for creating hybrid ISO+UDF images

Structs

CdWriter
Writer for creating hybrid ISO+UDF CD/DVD images

Enums

SeekFrom
Enumeration of possible methods to seek within an I/O object.

Traits

Read
The Read trait allows for reading bytes from a source.
Seek
The Seek trait provides a cursor which can be moved within a stream of bytes.
Write
A trait for objects which are byte-oriented sinks.